@@ -4,10 +4,12 @@ using namespace Rcpp;
 // [[Rcpp::export]]
 NumericVector calc_I_1(NumericMatrix X, int steps, float dt) {
   int i;
-  NumericVector I;
+  int paths = X.nrow();
+
+  NumericVector I(paths);
   I = X(_, steps)/2 * steps * dt * dt;
   for(i = 1; i < steps; i++) {
     I = I + X(_, i) * (i * dt) * dt;
-    }
+  }
   return I;
 }
